@@ -1,7 +1,5 @@
 package IO::All::File;
-use strict;
-use warnings;
-use IO::All '-Base';
+use IO::All -Base;
 use mixin 'IO::All::Filesys';
 use IO::File;
 
@@ -131,7 +129,7 @@ sub empty {
 
 sub filepath {
     my ($volume, $path) = $self->splitpath;
-    return File::Spec->catpath($volume, $path);
+    return File::Spec->catpath($volume, $path, '');
 }
 
 sub getline_backwards {
@@ -147,6 +145,28 @@ sub getlines_backwards {
     return @lines;
 }
 
+sub head {
+    my $lines = shift || 10;
+    my @return;
+    $self->close;
+    while ($lines--) {
+        push @return, ($self->getline or last);
+    }
+    $self->close;
+    return wantarray ? @return : join '', @return;
+}
+
+sub tail {
+    my $lines = shift || 10;
+    my @return;
+    $self->close;
+    while ($lines--) {
+        unshift @return, ($self->getline_backwards or last);
+    }
+    $self->close;
+    return wantarray ? @return : join '', @return;
+}
+
 sub touch {
     return super if -e $self->pathname;
     return $self if $self->is_open;
@@ -199,8 +219,6 @@ sub overload_file_as_scalar() {
     return \$scalar;
 }
 
-1;
-
 __DATA__
 
 =head1 NAME 
